@@ -1,5 +1,5 @@
 /*
- * @(#) $Id: cf.c 341 2023-10-06 21:02:44Z leres $ (XSE)
+ * @(#) $Id: cf.c 345 2023-10-10 19:56:04Z leres $ (XSE)
  *
  * Copyright (c) 1999, 2000, 2001, 2002, 2003, 2004, 2006, 2007, 2008, 2009, 2015, 2017, 2018, 2019, 2020, 2022, 2023
  *	Craig Leres
@@ -38,6 +38,12 @@
 #define DEF_MAXROW	10
 #define DEF_MAXCOL	5
 
+/* Globals */
+int debug;
+int errors;
+int verbose;
+const char *configfn = "webindex.conf";
+
 /* Forwards */
 static void addtz(struct cf *, struct tzlist *, const char *);
 static char *dstrmerge(char *, char *);
@@ -76,7 +82,6 @@ addtz(struct cf *cf, struct tzlist *tl, const char *at)
 
 	tl2 = cf->c_tzlist;
 	tl3 = NULL;
-	// XXX complain about duplicates or use last one seen?
 	while (tl2->t_start < tl->t_start) {
 		if (tl2->t_next == NULL) {
 			tl2->t_next = tl;
@@ -622,6 +627,7 @@ readcf(const char *fn, struct cf *cf, int mustexist)
 struct cf *
 parsecf(const char *fn)
 {
+	struct tzlist *tl, *tl2;
 	struct cf *cf;
 
 	cf = (struct cf *)calloc(1, sizeof(*cf));
@@ -681,6 +687,19 @@ parsecf(const char *fn)
 		cf->c_tzhours = 0;
 		++errors;
 	}
+
+	/* Look for duplicates */
+	tl = cf->c_tzlist;
+	for (; tl != NULL && tl->t_next != NULL; tl = tl->t_next) {
+		for (tl2 = tl->t_next; tl2 != NULL; tl2 = tl2->t_next) {
+			if (tl->t_start == tl2->t_start &&
+			    strcmp(tl->t_tz, tl2->t_tz) == 0) {
+				fprintf(stderr, "%s: Duplicate tz \"%s\"\n",
+				    prog, tl->t_tz);
+				++errors;
+			}
+		}
+	}
 	return (cf);
 }
 
