@@ -1,4 +1,4 @@
-/* @(#) $Id: cf.h 341 2023-10-06 21:02:44Z leres $ (XSE) */
+/* @(#) $Id: cf.h 345 2023-10-10 19:56:04Z leres $ (XSE) */
 #ifndef cf_h
 #define cf_h
 
@@ -98,7 +98,12 @@ struct cf {
 	struct tzlist *c_tzlist;
 };
 
-struct cf *parsecf(const char *);
-void freecf(struct cf *);
-const char *gettz(struct cf *, time_t);
+extern int debug;
+extern int errors;
+extern int verbose;
+extern const char *configfn;
+
+extern struct cf *parsecf(const char *);
+extern void freecf(struct cf *);
+extern const char *gettz(struct cf *, time_t);
 #endif
